package controller

import (
	"github.com/gin-gonic/gin"
	"trading-go/model"
	"trading-go/response"
)

// GetAllOrder
// @Tags 订单模块
// @Summary 获取所有订单
// @Produce application/json
// @Success 200 {object} response.Response
// @Router /order [get]
func GetAllOrder(c *gin.Context) {
	var orders []model.Order
	orders = append(orders, model.Order{})
	orders = append(orders, model.Order{})
	response.Success(c.Writer, "success", orders)
}

// GetUserOrder
// @Tags 订单模块
// @Summary 获取用户的所有订单
// @Produce application/json
// @Param id query int64 true "用户id"
// @Success 200 {object} response.Response
// @Router /order/user [get]
func GetUserOrder(c *gin.Context) {
	var orders []model.Order
	orders = append(orders, model.Order{})
	orders = append(orders, model.Order{})
	response.Success(c.Writer, "success", orders)
}

// ReviseOrder
// @Tags 订单模块
// @Summary 修改订单的状态
// @Produce application/json
// @Param id formData int64 true "订单id"
// @Param state formData int true "订单状态"
// @Success 200 {object} response.Response
// @Router /order/revise [post]
func ReviseOrder(c *gin.Context) {
	response.Success(c.Writer, "success", nil)
}

// CreateOrder
// @Tags 订单模块
// @Summary 创建订单
// @Produce application/json
// @Param json body model.OrderJson true "订单信息"
// @Success 200 {object} response.Response
// @Router /order/create [post]
func CreateOrder(c *gin.Context) {
	response.Success(c.Writer, "success", nil)
}

// DeleteOrder
// @Tags 订单模块
// @Summary 删除订单
// @Produce application/json
// @Param id path int64 true "订单id"
// @Success 200 {object} response.Response
// @Router /order/delete/{id} [delete]
func DeleteOrder(c *gin.Context) {
	response.Success(c.Writer, "success", nil)
}
